# NonComplianceSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**non_compliance_reference_number** | **str** |  | 
**non_compliance_date** | **datetime** |  | 
**non_compliance_status** | [**NonComplianceStatusResponse**](NonComplianceStatusResponse.md) |  | 
**non_compliance_status_string** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

